==> apache-camel-4.3.0-src.zip: apache-camel-4.3.0/components/camel-aws/camel-aws-config/src/test/java/org/apache/camel/component/aws/config/AWSConfigClientFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws.config;

import org.apache.camel.component.aws.config.client.AWSConfigClientFactory;
import org.apache.camel.component.aws.config.client.AWSConfigInternalClient;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientIAMOptimizedImpl;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientStandardImpl;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertTrue;

public class AWSConfigClientFactoryTest {

    @Test
    public void getStandardConfigClientDefault() {
        AWSConfigConfiguration configConfiguration = new AWSConfigConfiguration();
        AWSConfigInternalClient configClient = AWSConfigClientFactory.getConfigClient(configConfiguration);
        assertTrue(configClient instanceof AWSConfigClientStandardImpl);
    }

    @Test
    public void getStandardConfigClient() {
        AWSConfigConfiguration configConfiguration = new AWSConfigConfiguration();
        configConfiguration.setUseDefaultCredentialsProvider(false);
        AWSConfigInternalClient configClient = AWSConfigClientFactory.getConfigClient(configConfiguration);
        assertTrue(configClient instanceof AWSConfigClientStandardImpl);
    }

    @Test
    public void getIAMOptimizedConfigClient() {
        AWSConfigConfiguration configConfiguration = new AWSConfigConfiguration();
        configConfiguration.setUseDefaultCredentialsProvider(true);
        AWSConfigInternalClient configClient = AWSConfigClientFactory.getConfigClient(configConfiguration);
        assertTrue(configClient instanceof AWSConfigClientIAMOptimizedImpl);
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/components/camel-aws/camel-aws-config/src/test/java/org/apache/camel/component/aws/config/AWSConfigClientFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws.config;

import org.apache.camel.component.aws.config.client.AWSConfigClientFactory;
import org.apache.camel.component.aws.config.client.AWSConfigInternalClient;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientIAMOptimizedImpl;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientSessionTokenImpl;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientStandardImpl;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertTrue;

public class AWSConfigClientFactoryTest {

    @Test
    public void getStandardConfigClientDefault() {
        AWSConfigConfiguration configConfiguration = new AWSConfigConfiguration();
        AWSConfigInternalClient configClient = AWSConfigClientFactory.getConfigClient(configConfiguration);
        assertTrue(configClient instanceof AWSConfigClientStandardImpl);
    }

    @Test
    public void getStandardConfigClient() {
        AWSConfigConfiguration configConfiguration = new AWSConfigConfiguration();
        configConfiguration.setUseDefaultCredentialsProvider(false);
        AWSConfigInternalClient configClient = AWSConfigClientFactory.getConfigClient(configConfiguration);
        assertTrue(configClient instanceof AWSConfigClientStandardImpl);
    }

    @Test
    public void getIAMOptimizedConfigClient() {
        AWSConfigConfiguration configConfiguration = new AWSConfigConfiguration();
        configConfiguration.setUseDefaultCredentialsProvider(true);
        AWSConfigInternalClient configClient = AWSConfigClientFactory.getConfigClient(configConfiguration);
        assertTrue(configClient instanceof AWSConfigClientIAMOptimizedImpl);
    }

    @Test
    public void getSessionTokenConfigClient() {
        AWSConfigConfiguration configConfiguration = new AWSConfigConfiguration();
        configConfiguration.setUseSessionCredentials(true);
        AWSConfigInternalClient configClient = AWSConfigClientFactory.getConfigClient(configConfiguration);
        assertTrue(configClient instanceof AWSConfigClientSessionTokenImpl);
    }
}
